==> pointpos_api-0.2.0.tar.gz: test/item_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';

// tests for Item
void main() {
  var instance = new Item();

  group('test Item', () {
    // String id (default value: null)
    test('to test the property `id`', () async {
      // TODO
    });

    // String name (default value: null)
    test('to test the property `name`', () async {
      // TODO
    });

    // num categoryId (default value: null)
    test('to test the property `categoryId`', () async {
      // TODO
    });

    // String outletId (default value: null)
    test('to test the property `outletId`', () async {
      // TODO
    });

    // List<Image> images (default value: const [])
    test('to test the property `images`', () async {
      // TODO
    });

    // List<ItemVariants> variants (default value: const [])
    test('to test the property `variants`', () async {
      // TODO
    });

    // List<ItemInventory> inventory (default value: const [])
    test('to test the property `inventory`', () async {
      // TODO
    });

    // List<ItemCostOfGoodsSold> costOfGoodsSold (default value: const [])
    test('to test the property `costOfGoodsSold`', () async {
      // TODO
    });

    // String description (default value: null)
    test('to test the property `description`', () async {
      // TODO
    });

    // DateTime createdAt (default value: null)
    test('to test the property `createdAt`', () async {
      // TODO
    });

    // String createdBy (default value: null)
    test('to test the property `createdBy`', () async {
      // TODO
    });

    // DateTime updatedAt (default value: null)
    test('to test the property `updatedAt`', () async {
      // TODO
    });

    // String updatedBy (default value: null)
    test('to test the property `updatedBy`', () async {
      // TODO
    });

    // bool deleted (default value: null)
    test('to test the property `deleted`', () async {
      // TODO
    });


  });

}

==> pointpos_api-0.2.1.tar.gz: test/item_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';

// tests for Item
void main() {
  var instance = new Item();

  group('test Item', () {
    // String id (default value: null)
    test('to test the property `id`', () async {
      // TODO
    });

    // String name (default value: null)
    test('to test the property `name`', () async {
      // TODO
    });

    // num categoryId (default value: null)
    test('to test the property `categoryId`', () async {
      // TODO
    });

    // String outletId (default value: null)
    test('to test the property `outletId`', () async {
      // TODO
    });

    // List<Image> images (default value: const [])
    test('to test the property `images`', () async {
      // TODO
    });

    // List<UpdateItemVariants> variants (default value: const [])
    test('to test the property `variants`', () async {
      // TODO
    });

    // List<ItemAllOfInventory> inventory (default value: const [])
    test('to test the property `inventory`', () async {
      // TODO
    });

    // List<UpdateItemCostOfGoodsSold> costOfGoodsSold (default value: const [])
    test('to test the property `costOfGoodsSold`', () async {
      // TODO
    });

    // String description (default value: null)
    test('to test the property `description`', () async {
      // TODO
    });

    // DateTime createdAt (default value: null)
    test('to test the property `createdAt`', () async {
      // TODO
    });

    // String createdBy (default value: null)
    test('to test the property `createdBy`', () async {
      // TODO
    });

    // DateTime updatedAt (default value: null)
    test('to test the property `updatedAt`', () async {
      // TODO
    });

    // String updatedBy (default value: null)
    test('to test the property `updatedBy`', () async {
      // TODO
    });

    // bool deleted (default value: false)
    test('to test the property `deleted`', () async {
      // TODO
    });


  });

}
